![python version](https://img.shields.io/pypi/pyversions/music_bg?style=flat-square) ![Build status](https://img.shields.io/github/workflow/status/music-bg/music_bg/Release%20package?style=flat-square) [![version](https://img.shields.io/pypi/v/music_bg?style=flat-square)](https://pypi.org/project/music_bg/)


<div align="center">
<img src="https://raw.githubusercontent.com/music-bg/music_bg/master/images/logo.png" width=700>
</div>

<p align="center">
    <a href="https://github.com/music-bg/music_bg/wiki">Wiki</a> •
    <a href="#about">About</a> •
    <a href="#installation">Installation</a>
</p>

<div align="center">
<h1 id="about">About</h1>
</div>

This project is a dynamic wallpaper changer.
It waits untill you turn on the music,
downloads album cover if it's possible and
sets it as your wallpapper.

And the main thing, this project is highly customizable.
You can install plugins and write your own configurations.

<div align="center">
<h1 id="installation">Installation</h1>
</div>

⚠️ This project requires DBUS to be installed. Currently only linux is supported. ⚠️

To install this project simply run:
```bash
pip install music_bg
# Also you can install extra processors
# by running
pip install music_bg_extra
```

That's it. Now you can read our [wiki](https://github.com/music-bg/music_bg/wiki)
to set up your own music background.
